@@ -414,9 +414,10 @@ gst_spider_identity_sink_loop_type_finding (GstSpiderIdentity *ident)
   gboolean getmorebuf = TRUE;
   GList *type_list;
   gboolean restart_spider = FALSE;
+  GstCaps *caps;
 
   /* this should possibly be a property */
-  guint bufsizelimit = 4096;
+  guint bufsizelimit = 8192;
   
   /* checks - disable for speed */
   g_return_if_fail (ident != NULL);
@@ -447,27 +448,26 @@ gst_spider_identity_sink_loop_type_finding (GstSpiderIdentity *ident)
       /* handle DISCONT events, please */
     }
 
-    typefindbuf = buf;
-    getmorebuf = FALSE;
-    /* FIXME merging doesn't work for some reason so 
-     * we'll just typefind with the first element
     if (!typefindbuf){
       typefindbuf = buf;
-      gst_buffer_ref(buf);
     }
     else {
       GstBuffer *oldbuf = typefindbuf;
       typefindbuf = gst_buffer_merge(typefindbuf, buf);
-      gst_buffer_unref(oldbuf);
-      gst_buffer_unref(buf);
+      gst_buffer_unref (oldbuf);
+      gst_buffer_unref (buf);
     }
-    */
   }
   
   if (!typefindbuf){
     goto end;
   }
 
+  /* maybe there are already valid caps now? */
+  if ((caps = gst_pad_get_caps (ident->sink)) != NULL) {
+    goto plug;
+  }
+
   /* now do the actual typefinding with the supplied buffer */
   type_list = (GList *) gst_type_get_list ();
     
@@ -478,34 +478,23 @@ gst_spider_identity_sink_loop_type_finding (GstSpiderIdentity *ident)
     while (factories) {
       GstTypeFactory *factory = GST_TYPE_FACTORY (factories->data);
       GstTypeFindFunc typefindfunc = (GstTypeFindFunc)factory->typefindfunc;
-      GstCaps *caps;
 
-      if (typefindfunc && (caps = typefindfunc (buf, factory))) {
+      if (typefindfunc && (caps = typefindfunc (typefindbuf, factory))) {
 
-        /* pause the autoplugger */
-        if (gst_element_get_state (GST_ELEMENT (GST_ELEMENT_PARENT(ident))) == GST_STATE_PLAYING) {
-          gst_element_set_state (GST_ELEMENT (GST_ELEMENT_PARENT(ident)), GST_STATE_PAUSED);
-          restart_spider = TRUE;
-        }
 	if (gst_pad_try_set_caps (ident->sink, caps) <= 0) {
           g_warning ("typefind: found type but peer didn't accept it");
-	}
-        gst_spider_identity_plug (ident);  
-
-        /* restart autoplugger */
-        if (restart_spider){
-          gst_element_set_state (GST_ELEMENT (GST_ELEMENT_PARENT(ident)), GST_STATE_PLAYING);
-	}
-
-        goto end;
+          gst_caps_sink (caps);
+	} else {
+          goto plug;
+        }
       }
       factories = g_slist_next (factories);
     }
     type_list = g_list_next (type_list);
   }
   gst_element_error(GST_ELEMENT(ident), "Could not find media type", NULL);
-  gst_buffer_unref(buf);
-  buf = GST_BUFFER (gst_event_new (GST_EVENT_EOS));
+  gst_buffer_unref(typefindbuf);
+  typefindbuf = GST_BUFFER (gst_event_new (GST_EVENT_EOS));
 
 end:
 
@@ -514,7 +503,25 @@ end:
                                 (GstElementLoopFunction) GST_DEBUG_FUNCPTR (gst_spider_identity_dumb_loop));
   
   /* push the buffer */
-  gst_spider_identity_chain (ident->sink, buf);
+  gst_spider_identity_chain (ident->sink, typefindbuf);
+
+  return;
+
+plug:
+  gst_caps_debug (caps, "spider starting caps");
+  gst_caps_sink (caps);
+  /* pause the autoplugger */
+  if (gst_element_get_state (GST_ELEMENT (GST_ELEMENT_PARENT(ident))) == GST_STATE_PLAYING) {
+    gst_element_set_state (GST_ELEMENT (GST_ELEMENT_PARENT(ident)), GST_STATE_PAUSED);
+    restart_spider = TRUE;
+  }
+  gst_spider_identity_plug (ident);  
+
+  /* restart autoplugger */
+  if (restart_spider){
+    gst_element_set_state (GST_ELEMENT (GST_ELEMENT_PARENT(ident)), GST_STATE_PLAYING);
+  }
+  goto end;
 }
 
 static gboolean
