@@ -982,9 +982,7 @@ gst_element_add_ghost_pad (GstElement *element, GstPad *pad, const gchar *name)
 void
 gst_element_remove_ghost_pad (GstElement *element, GstPad *pad)
 {
-  g_return_if_fail (element != NULL);
   g_return_if_fail (GST_IS_ELEMENT (element));
-  g_return_if_fail (pad != NULL);
   g_return_if_fail (GST_IS_GHOST_PAD (pad));
 
   /* FIXME this is redundant?
@@ -992,8 +990,10 @@ gst_element_remove_ghost_pad (GstElement *element, GstPad *pad)
    * from the element. gst_pad_remove_ghost_pad just removes the ghostpad from
    * the real pad's ghost pad list
    */
-  gst_pad_remove_ghost_pad (GST_PAD (GST_PAD_REALIZE (pad)), pad);
+  gst_object_ref (GST_OBJECT (pad));
   gst_element_remove_pad (element, pad);
+  gst_pad_remove_ghost_pad (GST_PAD (GST_PAD_REALIZE (pad)), pad);
+  gst_object_unref (GST_OBJECT (pad));
 }
 
 
@@ -2098,6 +2098,14 @@ gst_element_set_state (GstElement *element, GstElementState state)
   /* start with the current state */
   curpending = GST_STATE(element);
 
+  if (state == curpending)
+  {
+    GST_DEBUG_ELEMENT (GST_CAT_STATES, element,
+                       "element is already in requested state %s",
+                       gst_element_state_get_name (state));
+    return (GST_STATE_SUCCESS);
+  }
+
   GST_DEBUG_ELEMENT (GST_CAT_STATES, element, "setting state from %s to %s",
                      gst_element_state_get_name (curpending),
                      gst_element_state_get_name (state));
@@ -2141,8 +2149,8 @@ gst_element_set_state (GstElement *element, GstElementState state)
          * did change the state... */
         if (GST_STATE (element) != curpending) {
           GST_DEBUG_ELEMENT (GST_CAT_STATES, element, 
-			     "element claimed state-change success,"
-			     "but state didn't change %s, %s <-> %s",
+			     "element claimed state-change success, "
+			     "but state didn't change (now %s, %s <-> %s",
                      	     gst_element_state_get_name (GST_STATE (element)),
                      	     gst_element_state_get_name (GST_STATE_PENDING (element)),
                      	     gst_element_state_get_name (curpending));
@@ -2709,13 +2717,13 @@ gst_element_state_get_name (GstElementState state)
   switch (state) {
 #ifdef GST_DEBUG_COLOR
     case GST_STATE_VOID_PENDING: return "NONE_PENDING";break;
-    case GST_STATE_NULL: return "\033[01;37mNULL\033[00m";break;
+    case GST_STATE_NULL: return "\033[01;34mNULL\033[00m";break;
     case GST_STATE_READY: return "\033[01;31mREADY\033[00m";break;
     case GST_STATE_PLAYING: return "\033[01;32mPLAYING\033[00m";break;
     case GST_STATE_PAUSED: return "\033[01;33mPAUSED\033[00m";break;
     default:
       /* This is a memory leak */
-      return g_strdup_printf ("\033[01;37;41mUNKNOWN!\033[00m(%d)", state);
+      return g_strdup_printf ("\033[01;35;41mUNKNOWN!\033[00m(%d)", state);
 #else
     case GST_STATE_VOID_PENDING: return "NONE_PENDING";break;
     case GST_STATE_NULL: return "NULL";break;
