@@ -134,6 +134,23 @@ gst_buffer_flag_get_type (void)
 }
 
 
+/* enumerations from "gstcaps.h" */
+GType
+gst_caps_flags_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { GST_CAPS_FIXED, "GST_CAPS_FIXED", "fixed" },
+      { GST_CAPS_FLOATING, "GST_CAPS_FLOATING", "floating" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static ("GstCapsFlags", values);
+  }
+  return etype;
+}
+
+
 /* enumerations from "gstclock.h" */
 GType
 gst_clock_entry_status_get_type (void)
@@ -286,6 +303,7 @@ gst_event_type_get_type (void)
       { GST_EVENT_RATE, "GST_EVENT_RATE", "rate" },
       { GST_EVENT_FILLER, "GST_EVENT_FILLER", "filler" },
       { GST_EVENT_TS_OFFSET, "GST_EVENT_TS_OFFSET", "ts-offset" },
+      { GST_EVENT_INTERRUPT, "GST_EVENT_INTERRUPT", "interrupt" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static ("GstEventType", values);
@@ -467,18 +485,18 @@ gst_index_flags_get_type (void)
 
 /* enumerations from "gstpad.h" */
 GType
-gst_pad_connect_return_get_type (void)
+gst_pad_link_return_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
-      { GST_PAD_CONNECT_REFUSED, "GST_PAD_CONNECT_REFUSED", "refused" },
-      { GST_PAD_CONNECT_DELAYED, "GST_PAD_CONNECT_DELAYED", "delayed" },
-      { GST_PAD_CONNECT_OK, "GST_PAD_CONNECT_OK", "ok" },
-      { GST_PAD_CONNECT_DONE, "GST_PAD_CONNECT_DONE", "done" },
+      { GST_PAD_LINK_REFUSED, "GST_PAD_LINK_REFUSED", "refused" },
+      { GST_PAD_LINK_DELAYED, "GST_PAD_LINK_DELAYED", "delayed" },
+      { GST_PAD_LINK_OK, "GST_PAD_LINK_OK", "ok" },
+      { GST_PAD_LINK_DONE, "GST_PAD_LINK_DONE", "done" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static ("GstPadConnectReturn", values);
+    etype = g_enum_register_static ("GstPadLinkReturn", values);
   }
   return etype;
 }
@@ -531,6 +549,21 @@ gst_pad_presence_get_type (void)
   return etype;
 }
 
+GType
+gst_pad_template_flags_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GST_PAD_TEMPLATE_FIXED, "GST_PAD_TEMPLATE_FIXED", "fixed" },
+      { GST_PAD_TEMPLATE_FLAG_LAST, "GST_PAD_TEMPLATE_FLAG_LAST", "flag-last" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GstPadTemplateFlags", values);
+  }
+  return etype;
+}
+
 
 /* enumerations from "gstplugin.h" */
 GType
@@ -576,6 +609,21 @@ gst_props_type_get_type (void)
   return etype;
 }
 
+GType
+gst_props_flags_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { GST_PROPS_FIXED, "GST_PROPS_FIXED", "fixed" },
+      { GST_PROPS_FLOATING, "GST_PROPS_FLOATING", "floating" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static ("GstPropsFlags", values);
+  }
+  return etype;
+}
+
 
 /* enumerations from "gstquery.h" */
 GType
@@ -701,7 +749,7 @@ gst_parse_error_get_type (void)
       { GST_PARSE_ERROR_SYNTAX, "GST_PARSE_ERROR_SYNTAX", "syntax" },
       { GST_PARSE_ERROR_NO_SUCH_ELEMENT, "GST_PARSE_ERROR_NO_SUCH_ELEMENT", "no-such-element" },
       { GST_PARSE_ERROR_NO_SUCH_PROPERTY, "GST_PARSE_ERROR_NO_SUCH_PROPERTY", "no-such-property" },
-      { GST_PARSE_ERROR_CONNECT, "GST_PARSE_ERROR_CONNECT", "connect" },
+      { GST_PARSE_ERROR_LINK, "GST_PARSE_ERROR_LINK", "link" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static ("GstParseError", values);
