@@ -29,7 +29,6 @@
 #define STATUS(A)
 #endif
 
-#include <pthread.h>
 
 #include "config.h"
 #include "gst_private.h"
@@ -112,7 +111,7 @@ queue_leaky_get_type(void) {
 }
 
 static GstElementClass *parent_class = NULL;
-/* static guint gst_queue_signals[LAST_SIGNAL] = { 0 }; */
+static guint gst_queue_signals[LAST_SIGNAL] = { 0 };
 
 GType
 gst_queue_get_type(void) 
@@ -148,6 +147,12 @@ gst_queue_class_init (GstQueueClass *klass)
 
   parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
 
+  gst_queue_signals[HIGH_WATERMARK] =
+    g_signal_new ("high_watermark", G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_FIRST,
+                  G_STRUCT_OFFSET (GstQueueClass, high_watermark), NULL, NULL,
+                  g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1,
+                  G_TYPE_INT);
+
   g_object_class_install_property (G_OBJECT_CLASS (klass), ARG_LEAKY,
     g_param_spec_enum ("leaky", "Leaky", "Where the queue leaks, if at all.",
                        GST_TYPE_QUEUE_LEAKY, GST_QUEUE_NO_LEAK, G_PARAM_READWRITE));
@@ -174,8 +179,8 @@ gst_queue_class_init (GstQueueClass *klass)
   gstelement_class->release_locks = GST_DEBUG_FUNCPTR(gst_queue_release_locks);
 }
 
-static GstPadConnectReturn
-gst_queue_connect (GstPad *pad, GstCaps *caps)
+static GstPadLinkReturn
+gst_queue_link (GstPad *pad, GstCaps *caps)
 {
   GstQueue *queue = GST_QUEUE (gst_pad_get_parent (pad));
   GstPad *otherpad;
@@ -185,7 +190,7 @@ gst_queue_connect (GstPad *pad, GstCaps *caps)
   else
     otherpad = queue->srcpad;
 
-  return gst_pad_proxy_connect (otherpad, caps);
+  return gst_pad_proxy_link (otherpad, caps);
 }
 
 static GstCaps*
@@ -195,11 +200,14 @@ gst_queue_getcaps (GstPad *pad, GstCaps *caps)
   GstPad *otherpad;
 
   if (pad == queue->srcpad) 
-    otherpad = queue->sinkpad;
+    otherpad = GST_PAD_PEER (queue->sinkpad);
   else
-    otherpad = queue->srcpad;
+    otherpad = GST_PAD_PEER (queue->srcpad);
 
-  return gst_pad_get_allowed_caps (otherpad);
+  if (otherpad)
+    return gst_pad_get_caps (otherpad);
+
+  return NULL;
 }
 
 static void
@@ -213,13 +221,13 @@ gst_queue_init (GstQueue *queue)
   gst_pad_set_chain_function (queue->sinkpad, GST_DEBUG_FUNCPTR (gst_queue_chain));
   gst_element_add_pad (GST_ELEMENT (queue), queue->sinkpad);
   gst_pad_set_bufferpool_function (queue->sinkpad, GST_DEBUG_FUNCPTR (gst_queue_get_bufferpool));
-  gst_pad_set_connect_function (queue->sinkpad, GST_DEBUG_FUNCPTR (gst_queue_connect));
+  gst_pad_set_link_function (queue->sinkpad, GST_DEBUG_FUNCPTR (gst_queue_link));
   gst_pad_set_getcaps_function (queue->sinkpad, GST_DEBUG_FUNCPTR (gst_queue_getcaps));
 
   queue->srcpad = gst_pad_new ("src", GST_PAD_SRC);
   gst_pad_set_get_function (queue->srcpad, GST_DEBUG_FUNCPTR (gst_queue_get));
   gst_element_add_pad (GST_ELEMENT (queue), queue->srcpad);
-  gst_pad_set_connect_function (queue->srcpad, GST_DEBUG_FUNCPTR (gst_queue_connect));
+  gst_pad_set_link_function (queue->srcpad, GST_DEBUG_FUNCPTR (gst_queue_link));
   gst_pad_set_getcaps_function (queue->srcpad, GST_DEBUG_FUNCPTR (gst_queue_getcaps));
   gst_pad_set_event_function (queue->srcpad, GST_DEBUG_FUNCPTR (gst_queue_handle_src_event));
 
@@ -251,6 +259,8 @@ gst_queue_dispose (GObject *object)
 {
   GstQueue *queue = GST_QUEUE (object);
 
+  gst_element_set_state (GST_ELEMENT (queue), GST_STATE_NULL);
+
   g_mutex_free (queue->qlock);
   g_cond_free (queue->not_empty);
   g_cond_free (queue->not_full);
@@ -320,9 +330,9 @@ gst_queue_chain (GstPad *pad, GstBuffer *buf)
 
 restart:
   /* we have to lock the queue since we span threads */
-  GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "locking t:%ld", pthread_self ());
+  GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "locking t:%p", g_thread_self ());
   g_mutex_lock (queue->qlock);
-  GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "locked t:%ld", pthread_self ());
+  GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "locked t:%p", g_thread_self ());
 
   /* assume don't need to flush this buffer when the queue is filled */
   queue->flush = FALSE;
@@ -346,6 +356,11 @@ restart:
   GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "adding buffer %p of size %d",buf,GST_BUFFER_SIZE(buf));
 
   if (queue->level_buffers == queue->size_buffers) {
+    g_mutex_unlock (queue->qlock);
+    g_signal_emit (G_OBJECT (queue), gst_queue_signals[HIGH_WATERMARK], 0,
+                   queue->level_buffers);
+    g_mutex_lock (queue->qlock);
+
     /* if this is a leaky queue... */
     if (queue->leaky) {
       /* FIXME don't want to leak events! */
@@ -472,9 +487,9 @@ gst_queue_get (GstPad *pad)
 
 restart:
   /* have to lock for thread-safety */
-  GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "locking t:%ld", pthread_self ());
+  GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "locking t:%p", g_thread_self ());
   g_mutex_lock (queue->qlock);
-  GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "locked t:%ld %p", pthread_self (), queue->not_empty);
+  GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "locked t:%p %p", g_thread_self (), queue->not_empty);
 
   GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "pre empty wait, level:%d/%d", queue->level_buffers, queue->size_buffers);
   while (queue->level_buffers == 0) {
@@ -486,7 +501,7 @@ restart:
       GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "interrupted!!");
       g_mutex_unlock (queue->qlock);
       if (gst_scheduler_interrupt (gst_pad_get_scheduler (queue->srcpad), GST_ELEMENT (queue)))
-        return NULL;
+        return GST_BUFFER (gst_event_new (GST_EVENT_INTERRUPT));
       goto restart;
     }
     if (GST_STATE (queue) != GST_STATE_PLAYING) {
@@ -572,6 +587,8 @@ gst_queue_handle_src_event (GstPad *pad, GstEvent *event)
 {
   GstQueue *queue;
   gboolean res;
+  gint event_type;
+  gint flag_flush = 0;
 
   queue = GST_QUEUE (GST_OBJECT_PARENT (pad));
 
@@ -580,30 +597,37 @@ gst_queue_handle_src_event (GstPad *pad, GstEvent *event)
   if (gst_element_get_state (GST_ELEMENT (queue)) == GST_STATE_PLAYING) {
     /* push the event to the queue for upstream consumption */
     g_async_queue_push(queue->events, event);
-    g_mutex_unlock (queue->qlock);
     g_warning ("FIXME: sending event in a running queue");
     /* FIXME wait for delivery of the event here, then return the result
      * instead of FALSE */
-    return FALSE;
+    res = FALSE;
+    goto done;
   }
 
+  event_type = GST_EVENT_TYPE (event);
+  if (event_type == GST_EVENT_SEEK)
+    flag_flush = GST_EVENT_SEEK_FLAGS (event) & GST_SEEK_FLAG_FLUSH;
+
   res = gst_pad_event_default (pad, event); 
-  switch (GST_EVENT_TYPE (event)) {
+
+  switch (event_type) {
     case GST_EVENT_FLUSH:
       GST_DEBUG_ELEMENT (GST_CAT_DATAFLOW, queue, "FLUSH event, flushing queue\n");
       gst_queue_locked_flush (queue);
       break;
     case GST_EVENT_SEEK:
-      if (GST_EVENT_SEEK_FLAGS (event) & GST_SEEK_FLAG_FLUSH) {
+      if (flag_flush) {
         gst_queue_locked_flush (queue);
       }
     default:
       break;
   }
+
+done:
   g_mutex_unlock (queue->qlock);
 
   /* we have to claim success, but we don't really know */
-  return TRUE;
+  return res;
 }
 
 static gboolean
@@ -627,8 +651,6 @@ gst_queue_change_state (GstElement *element)
 {
   GstQueue *queue;
   GstElementStateReturn ret;
-  GstElementState new_state;
-  g_return_val_if_fail (GST_IS_QUEUE (element), GST_STATE_FAILURE);
 
   queue = GST_QUEUE (element);
 
@@ -639,25 +661,53 @@ gst_queue_change_state (GstElement *element)
    */
   g_mutex_lock (queue->qlock);
 
-  new_state = GST_STATE_PENDING (element);
+  switch (GST_STATE_TRANSITION (element)) {
+    case GST_STATE_NULL_TO_READY:
+      gst_queue_locked_flush (queue);
+      break;
+    case GST_STATE_READY_TO_PAUSED:
+      break;
+    case GST_STATE_PAUSED_TO_PLAYING:
+      if (!GST_PAD_IS_LINKED (queue->sinkpad)) {
+        GST_DEBUG_ELEMENT (GST_CAT_STATES, queue, "queue %s is not linked", GST_ELEMENT_NAME (queue));
+        /* FIXME can this be? */
+        if (queue->reader)
+          g_cond_signal (queue->not_empty);
 
-  if (new_state == GST_STATE_READY) {
-    gst_queue_locked_flush (queue);
-  }
-  else if (new_state == GST_STATE_PLAYING) {
-    if (!GST_PAD_IS_USABLE (queue->sinkpad)) {
-      GST_DEBUG_ELEMENT (GST_CAT_STATES, queue, "queue %s is not connected", GST_ELEMENT_NAME (queue));
-      /* FIXME can this be? */
-      if (queue->reader)
-        g_cond_signal (queue->not_empty);
-      g_mutex_unlock (queue->qlock);
+        ret = GST_STATE_FAILURE;
+        goto error;
+      }
+      else {
+        GstScheduler *src_sched, *sink_sched;
+	    
+        src_sched = gst_pad_get_scheduler (GST_PAD_CAST (queue->srcpad));
+        sink_sched = gst_pad_get_scheduler (GST_PAD_CAST (queue->sinkpad));
 
-      return GST_STATE_FAILURE;
-    }
-    queue->interrupt = FALSE;
+        if (src_sched == sink_sched) {
+          GST_DEBUG_ELEMENT (GST_CAT_STATES, queue, "queue %s does not connect different schedulers", 
+			GST_ELEMENT_NAME (queue));
+
+	  g_warning ("queue %s does connect different schedulers",
+			GST_ELEMENT_NAME (queue));
+
+	  ret = GST_STATE_FAILURE;
+	  goto error;
+        }
+      }
+      queue->interrupt = FALSE;
+      break;
+    case GST_STATE_PLAYING_TO_PAUSED:
+      break;
+    case GST_STATE_PAUSED_TO_READY:
+      gst_queue_locked_flush (queue);
+      break;
+    case GST_STATE_READY_TO_NULL:
+      break;
   }
 
   ret = GST_ELEMENT_CLASS (parent_class)->change_state (element);
+
+error:
   g_mutex_unlock (queue->qlock);
 
   GST_DEBUG_LEAVE("('%s')", GST_ELEMENT_NAME (element));
