@@ -28,6 +28,18 @@
 
 /* #define BS_DEBUG */
 
+#ifdef G_HAVE_ISO_VARARGS
+
+#ifdef BS_DEBUG
+# define bs_print(...)	GST_DEBUG (GST_CAT_BUFFER, __VA_ARGS__)
+# define bs_status(bs)			gst_bytestream_print_status(bs)
+#else
+# define bs_print(...)
+# define bs_status(bs)
+#endif
+
+#elif defined(G_HAVE_GNUC_VARARGS)
+
 #ifdef BS_DEBUG
 # define bs_print(format,args...)	GST_DEBUG (GST_CAT_BUFFER,  format, ## args)
 # define bs_status(bs)			gst_bytestream_print_status(bs)
@@ -36,7 +48,9 @@
 # define bs_status(bs)
 #endif
 
-guint8 *gst_bytestream_assemble (GstByteStream * bs, guint32 len);
+#endif
+
+static guint8 *gst_bytestream_assemble (GstByteStream * bs, guint32 len);
 
 /**
  * gst_bytestream_new:
@@ -118,10 +132,11 @@ gst_bytestream_destroy (GstByteStream * bs)
  * else add it onto the head of the 
  */
 static gboolean
-gst_bytestream_get_next_buf (GstByteStream * bs)
+gst_bytestream_get_next_buf (GstByteStream *bs)
 {
   GstBuffer *nextbuf, *lastbuf, *headbuf;
   GSList *end;
+  GstClockTime ts;
 
   /* if there is an event pending, return FALSE */
   if (bs->event)
@@ -130,15 +145,17 @@ gst_bytestream_get_next_buf (GstByteStream * bs)
   bs_print ("get_next_buf: pulling buffer");
   nextbuf = gst_pad_pull (bs->pad);
 
+  if (!nextbuf)
+    return FALSE;
+
   if (GST_IS_EVENT (nextbuf)) {
     bs->event = GST_EVENT (nextbuf);
     return FALSE;
   }
 
-  if (!nextbuf)
-    return FALSE;
-
-  bs->last_ts = GST_BUFFER_TIMESTAMP (nextbuf);
+  ts = GST_BUFFER_TIMESTAMP (nextbuf);
+  if (ts != GST_CLOCK_TIME_NONE)
+    bs->last_ts = ts;
 
   bs_print ("get_next_buf: got buffer of %d bytes", GST_BUFFER_SIZE (nextbuf));
 
@@ -197,7 +214,7 @@ gst_bytestream_get_next_buf (GstByteStream * bs)
 }
 
 static gboolean
-gst_bytestream_fill_bytes (GstByteStream * bs, guint32 len)
+gst_bytestream_fill_bytes (GstByteStream *bs, guint32 len)
 {
   /* as long as we don't have enough, we get more buffers */
   while (bs->listavail < len) {
@@ -209,9 +226,8 @@ gst_bytestream_fill_bytes (GstByteStream * bs, guint32 len)
   return TRUE;
 }
 
-
 guint32
-gst_bytestream_peek (GstByteStream * bs, GstBuffer **buf, guint32 len)
+gst_bytestream_peek (GstByteStream *bs, GstBuffer **buf, guint32 len)
 {
   GstBuffer *headbuf, *retbuf = NULL;
 
@@ -223,9 +239,9 @@ gst_bytestream_peek (GstByteStream * bs, GstBuffer **buf, guint32 len)
   /* make sure we have enough */
   bs_print ("peek: there are %d bytes in the list", bs->listavail);
   if (len > bs->listavail) {
-    if (!gst_bytestream_fill_bytes (bs, len)){
+    if (!gst_bytestream_fill_bytes (bs, len)) {
       /* we must have an event coming up */
-      if (bs->listavail > 0){
+      if (bs->listavail > 0) {
         /* we have some data left, len will be shrunk to the amount of data available */
         len = bs->listavail;
       }
@@ -267,7 +283,7 @@ gst_bytestream_peek (GstByteStream * bs, GstBuffer **buf, guint32 len)
 }
 
 guint32
-gst_bytestream_peek_bytes (GstByteStream * bs, guint8** data, guint32 len)
+gst_bytestream_peek_bytes (GstByteStream *bs, guint8** data, guint32 len)
 {
   GstBuffer *headbuf;
 
@@ -322,8 +338,8 @@ gst_bytestream_peek_bytes (GstByteStream * bs, guint8** data, guint32 len)
   return len;
 }
 
-guint8 *
-gst_bytestream_assemble (GstByteStream * bs, guint32 len)
+static guint8*
+gst_bytestream_assemble (GstByteStream *bs, guint32 len)
 {
   guint8 *data = g_malloc (len);
   GSList *walk;
@@ -358,10 +374,13 @@ gst_bytestream_assemble (GstByteStream * bs, guint32 len)
 }
 
 gboolean
-gst_bytestream_flush (GstByteStream * bs, guint32 len)
+gst_bytestream_flush (GstByteStream *bs, guint32 len)
 {
   bs_print ("flush: flushing %d bytes", len);
 
+  if (len == 0)
+    return TRUE;
+
   /* make sure we have enough */
   bs_print ("flush: there are %d bytes in the list", bs->listavail);
   if (len > bs->listavail) {
@@ -376,10 +395,13 @@ gst_bytestream_flush (GstByteStream * bs, guint32 len)
 }
 
 void
-gst_bytestream_flush_fast (GstByteStream * bs, guint32 len)
+gst_bytestream_flush_fast (GstByteStream *bs, guint32 len)
 {
   GstBuffer *headbuf;
 
+  if (len == 0)
+    return;
+		  
   g_assert (len <= bs->listavail);
 
   if (bs->assembled) {
@@ -394,7 +416,7 @@ gst_bytestream_flush_fast (GstByteStream * bs, guint32 len)
   while (len > 0) {
     headbuf = GST_BUFFER (bs->buflist->data);
 
-    bs_print ("flush: analyzing buffer that's %d bytes long, offset %d", GST_BUFFER_SIZE (headbuf),
+    bs_print ("flush: analyzing buffer that's %d bytes long, offset %llu", GST_BUFFER_SIZE (headbuf),
 	      GST_BUFFER_OFFSET (headbuf));
 
     /* if there's enough to complete the flush */
@@ -443,10 +465,10 @@ gst_bytestream_seek (GstByteStream *bs, gint64 offset, GstSeekType method)
 
   bs_print ("bs: send event\n");
   if (gst_pad_send_event (GST_PAD (peer), gst_event_new_seek (
-				  GST_FORMAT_BYTES | 
-				  (method & GST_SEEK_METHOD_MASK) | 
-				  GST_SEEK_FLAG_FLUSH | GST_SEEK_FLAG_ACCURATE, 
-				  offset))) 
+			  GST_FORMAT_BYTES | 
+			  (method & GST_SEEK_METHOD_MASK) | 
+			  GST_SEEK_FLAG_FLUSH | GST_SEEK_FLAG_ACCURATE, 
+			  offset))) 
   {
     gst_bytestream_flush_fast (bs, bs->listavail);
 
@@ -470,8 +492,9 @@ gst_bytestream_tell (GstByteStream *bs)
 
   format = GST_FORMAT_BYTES;
 
-  if (gst_pad_query (GST_PAD_PEER (bs->pad), GST_PAD_QUERY_POSITION, &format, &value)) 
-    return value;
+  if (gst_pad_query (GST_PAD_PEER (bs->pad), GST_QUERY_POSITION, &format, &value)) {
+    return value - bs->listavail;
+  }
   
   return -1;
 }
@@ -486,14 +509,14 @@ gst_bytestream_length (GstByteStream *bs)
 
   format = GST_FORMAT_BYTES;
 
-  if (gst_pad_query (GST_PAD_PEER (bs->pad), GST_PAD_QUERY_TOTAL, &format, &value)) 
+  if (gst_pad_query (GST_PAD_PEER (bs->pad), GST_QUERY_TOTAL, &format, &value)) 
     return value;
   
   return -1;
 }
 
 guint32
-gst_bytestream_read (GstByteStream * bs, GstBuffer** buf, guint32 len)
+gst_bytestream_read (GstByteStream *bs, GstBuffer** buf, guint32 len)
 {
   guint32 len_peeked;
 
@@ -545,17 +568,16 @@ gst_bytestream_size_hint (GstByteStream *bs, guint32 size)
  */
 void
 gst_bytestream_get_status (GstByteStream *bs,
-			   guint32 *avail_out,
-			   GstEvent **event_out)
+			   guint32 	 *avail_out,
+			   GstEvent 	**event_out)
 {
   if (avail_out)
     *avail_out = bs->listavail;
 
-  if (event_out)
-    {
-      *event_out = bs->event;
-      bs->event = NULL;
-    }
+  if (event_out) {
+    *event_out = bs->event;
+    bs->event = NULL;
+  }
 }
 
 /**
@@ -604,7 +626,7 @@ gst_bytestream_print_status (GstByteStream * bs)
     buf = GST_BUFFER (walk->data);
     walk = g_slist_next (walk);
 
-    bs_print ("STATUS: buffer starts at %d and is %d bytes long", GST_BUFFER_OFFSET (buf), GST_BUFFER_SIZE (buf));
+    bs_print ("STATUS: buffer starts at %llu and is %d bytes long", GST_BUFFER_OFFSET (buf), GST_BUFFER_SIZE (buf));
   }
 }
 
