@@ -12,7 +12,7 @@ create_pipeline (void)
   fakesrc = gst_element_factory_make ("fakesrc", "fakesrc");
   fakesink = gst_element_factory_make ("fakesink", "fakesink");
 
-  gst_element_connect (fakesrc, fakesink);
+  gst_element_link (fakesrc, fakesink);
 
   gst_bin_add_many (GST_BIN (pipeline), fakesrc, fakesink, NULL);
 
