@@ -30,7 +30,7 @@ main (gint argc, gchar *argv[])
 
     fakesink = gst_element_factory_make ("fakesink", "fakesink");
 
-    gst_element_connect (fakesrc, fakesink);
+    gst_element_link (fakesrc, fakesink);
 
     gst_bin_add (GST_BIN (bin), fakesink);
     gst_bin_add (GST_BIN (pipeline), bin);
